@@ -181,6 +181,26 @@ make_property!(
     "sRGB" => Srgb,
 );
 
+make_property!(
+    /// `cx` attribute.
+    ///
+    /// https://www.w3.org/TR/SVG2/geometry.html#CX
+    CX,
+    default: Length::<Horizontal>::parse_str("0").unwrap(),
+    inherits_automatically: false,
+    newtype_parse: Length<Horizontal>,
+);
+
+make_property!(
+    /// `cy` attribute.
+    ///
+    /// https://www.w3.org/TR/SVG2/geometry.html#CY
+    CY,
+    default: Length::<Vertical>::parse_str("0").unwrap(),
+    inherits_automatically: false,
+    newtype_parse: Length<Vertical>,
+);
+
 make_property!(
     /// `direction` property.
     ///
@@ -510,6 +530,16 @@ make_property!(
     inherits_automatically: false,
 );
 
+make_property!(
+    /// `height` attribute.
+    ///
+    /// https://www.w3.org/TR/SVG2/geometry.html#Sizing
+    Height,
+    default: LengthOrAuto::<Vertical>::Auto,
+    inherits_automatically: false,
+    newtype_parse: LengthOrAuto<Vertical>,
+);
+
 make_property!(
     /// `isolation` property.
     ///
@@ -774,6 +804,36 @@ fn parses_paint_order() {
     assert!(PaintOrder::parse_str("markers stroke fill hello").is_err());
 }
 
+make_property!(
+    /// `r` attribute.
+    ///
+    /// https://www.w3.org/TR/SVG2/geometry.html#R
+    R,
+    default: ULength::<Both>::parse_str("0").unwrap(),
+    inherits_automatically: false,
+    newtype_parse: ULength<Both>,
+);
+
+make_property!(
+    /// `rx` attribute.
+    ///
+    /// https://www.w3.org/TR/SVG2/geometry.html#RX
+    RX,
+    default: LengthOrAuto::<Horizontal>::Auto,
+    inherits_automatically: false,
+    newtype_parse: LengthOrAuto<Horizontal>,
+);
+
+make_property!(
+    /// `ry` attribute.
+    ///
+    /// https://www.w3.org/TR/SVG2/geometry.html#RY
+    RY,
+    default: LengthOrAuto::<Vertical>::Auto,
+    inherits_automatically: false,
+    newtype_parse: LengthOrAuto<Vertical>,
+);
+
 make_property!(
     /// `shape-rendering` property.
     ///
@@ -1058,7 +1118,6 @@ make_property!(
     /// `transform` property.
     ///
     /// https://www.w3.org/TR/css-transforms-1/#transform-property
-    #[allow(unused)]
     Transform,
     default: TransformProperty::None,
     inherits_automatically: false,
@@ -1098,6 +1157,16 @@ make_property!(
     "collapse" => Collapse,
 );
 
+make_property!(
+    /// `width` attribute.
+    ///
+    /// https://www.w3.org/TR/SVG2/geometry.html#Sizing
+    Width,
+    default: LengthOrAuto::<Horizontal>::Auto,
+    inherits_automatically: false,
+    newtype_parse: LengthOrAuto<Horizontal>,
+);
+
 make_property!(
     /// `writing-mode` property.
     ///
@@ -1148,6 +1217,16 @@ impl WritingMode {
     }
 }
 
+make_property!(
+    /// `x` attribute.
+    ///
+    /// https://www.w3.org/TR/SVG2/geometry.html#X
+    X,
+    default: Length::<Horizontal>::parse_str("0").unwrap(),
+    inherits_automatically: false,
+    newtype_parse: Length<Horizontal>,
+);
+
 make_property!(
     /// `xml:lang` attribute.
     ///
@@ -1205,3 +1284,13 @@ make_property!(
     "default" => Default,
     "preserve" => Preserve,
 );
+
+make_property!(
+    /// `y` attribute.
+    ///
+    /// https://www.w3.org/TR/SVG2/geometry.html#Y
+    Y,
+    default: Length::<Vertical>::parse_str("0").unwrap(),
+    inherits_automatically: false,
+    newtype_parse: Length<Vertical>,
+);
